import os
import glob
import webbrowser
from langdetect import detect, DetectorFactory
from sumy.parsers.plaintext import PlaintextParser
from sumy.nlp.tokenizers import Tokenizer
from sumy.summarizers.text_rank import TextRankSummarizer
import nltk
from nltk.tokenize import word_tokenize

DetectorFactory.seed = 0
nltk.download('punkt')

SUPPORTED_LANGUAGES = {'en', 'pl', 'fr', 'de', 'es', 'it', 'ru', 'zh-cn', 'ja', 'pt', 'nl', 'ar'}

def detect_language(text):
    try:
        detected_lang = detect(text)
        if detected_lang in SUPPORTED_LANGUAGES:
            return detected_lang
        else:
            print(f"Detected language '{detected_lang}' is not supported. Defaulting to English.")
            return 'en'
    except Exception as e:
        print(f"An error occurred during language detection: {e}")
        return 'en'

def tokenize_text(text):
    words = word_tokenize(text.lower())
    return words

def save_and_display_summary(original_text, summary_text, original_word_count, summary_word_count, file_name):
    html_content = f"""
    <html>
    <head>
        <title>Text Summary</title>
        <style>
            body {{ font-family: Arial, sans-serif; line-height: 1.6; margin: 20px; text-align: center; }}
            .box {{ border: 1px solid #ccc; padding: 20px; border-radius: 10px; margin-bottom: 20px; display: inline-block; text-align: left; width: 60%; }}
            .centered-box p {{ text-align: center; }}
        </style>
    </head>
    <body>
        <h2>Original Text</h2>
        <div class="box">
            <p>{original_text.replace('\n', '<br>')}</p>
        </div>
        <h2>Summary</h2>
        <div class="box">
            <p>{summary_text.replace('\n', '<br>')}</p>
        </div>
        <h2>Summary Statistics</h2>
        <div class="box centered-box">
            <p>Original word count: {original_word_count}</p>
            <p>Summary word count: {summary_word_count}</p>
        </div>
    </body>
    </html>
    """
    file_path = file_name.replace('.txt', '.html')
    with open(file_path, 'w', encoding='utf-8') as file:
        file.write(html_content)
    
    webbrowser.open('file://' + os.path.realpath(file_path))

def summarize_with_text_rank(file_path, summary_percentage):
    try:
        with open(file_path, 'r', encoding='utf-8') as file:
            text = file.read()

        language = detect_language(text)
        print(f"Detected language: {language}")

        parser = PlaintextParser.from_string(text, Tokenizer(language))
        summarizer = TextRankSummarizer()

        total_sentences = len(list(parser.document.sentences))
        summary_sentence_count = max(1, int(total_sentences * (summary_percentage / 100)))

        summary = summarizer(parser.document, summary_sentence_count)

        summary_text = " ".join([str(sentence) for sentence in summary])
        print("\nSummary:", summary_text)

        original_words = tokenize_text(text)
        summary_words = tokenize_text(summary_text)

        original_word_count = len(original_words)
        summary_word_count = len(summary_words)

        print(f"\nOriginal word count: {original_word_count}")
        print(f"Summary word count: {summary_word_count}")

        save_and_display_summary(text, summary_text, original_word_count, summary_word_count, file_path)
    except Exception as e:
        print(f"An error occurred: {e}")

def main():
    txt_files = glob.glob("*.txt")
    
    if not txt_files:
        print("No text files found in the current directory.")
        return

    print("Select a text file to summarize:")
    for i, file_name in enumerate(txt_files, start=1):
        print(f"{i}. {file_name}")

    file_choice = int(input("\nEnter the number of the file: ")) - 1

    if file_choice < 0 or file_choice >= len(txt_files):
        print("Invalid choice.")
        return

    file_path = txt_files[file_choice]
    summary_percentage = float(input("Enter the percentage of the text to keep in the summary (e.g., 30 for 30%): "))

    summarize_with_text_rank(file_path, summary_percentage)

if __name__ == "__main__":
    main()
